//
//  Animations.swift
//  SwiftUI for beginners
//
//  Created by Johan Sas on 02/09/2024.
//

import SwiftUI

struct Animations: View {
    
    @State var isExpanded = false
    
    @State var showDetail = false
    var body: some View {
        VStack {
            Circle()
                .fill(isExpanded ? .blue : .green)
                .frame(width: isExpanded ? 200 : 100, height: isExpanded ? 200 : 100)
                .animation(.spring(response: 0.5, dampingFraction: 0.5, blendDuration: 1), value: isExpanded)
            
            Button("Toggle Animation") {
                withAnimation {
                    isExpanded.toggle()
                }
            }.padding(.top, 20)
        }
        VStack {
            Button("Toggle Detail"){
                withAnimation {
                    showDetail.toggle()
                }
            }
            .padding(.top, 20)
            if showDetail {
                RoundedRectangle(cornerRadius: 25.0)
                    .fill(.blue)
                    .frame(width: 300, height: 200)
                    .transition(.scaleAndFade)
            }
        }
    }
}


extension AnyTransition {
    static var scaleAndFade: AnyTransition {
        AnyTransition.scale.combined(with: .opacity)
    }
}


#Preview {
    Animations()
}
